Module: PatientHttp
- Defined in:
- lib/patient_http/sidekiq.rb,
lib/patient_http/sidekiq/stats.rb,
lib/patient_http/sidekiq/web_ui.rb,
lib/patient_http/sidekiq/context.rb,
lib/patient_http/sidekiq/task_handler.rb,
lib/patient_http/sidekiq/task_monitor.rb,
lib/patient_http/sidekiq/configuration.rb,
lib/patient_http/sidekiq/request_worker.rb,
lib/patient_http/sidekiq/callback_worker.rb,
lib/patient_http/sidekiq/lifecycle_hooks.rb,
lib/patient_http/sidekiq/request_executor.rb,
lib/patient_http/sidekiq/processor_observer.rb,
lib/patient_http/sidekiq/task_monitor_thread.rb
Overview
Sidekiq server lifecycle hooks for automatic Sidekiq processor management.
This class registers lifecycle hooks with Sidekiq to automatically start, drain, and stop the Sidekiq processor along with the Sidekiq server.
The hooks will:
-
Start the processor when Sidekiq server starts (:startup event)
-
Drain the processor when Sidekiq receives TSTP signal (:quiet event)
-
Stop the processor when Sidekiq shuts down (:shutdown event)
Defined Under Namespace
Modules: Sidekiq